pub enum DeribitUpdateInterval {
Raw,
Ms100,
Agg2,
}Expand description
Deribit data stream update intervals.
Controls how frequently updates are sent for subscribed channels. Raw updates require authentication while aggregated updates are public.
Variants
Raw
Raw updates - immediate delivery of each event. Requires authentication.
Ms100
Aggregated updates every 100 milliseconds (default).
Agg2
Aggregated updates every 2 ticks.
Implementations